package SQL::Translator::Schema::Graph::Port;

use strict;

use vars qw[ $VERSION ];
$VERSION = '1.60';

1;
